//---- Rex's Body & Helmet

//  Original file by Mike Miller
//
//  Modified for POV-Ray version 3.x by
//  Colin Fleming, cj_fleming@btinternet.com
//


// Declared Body Parts
//^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

//--- Torus for Helmet Neck 
#declare T1 = 
quartic {
	<1, 0, 0, 0, 2, 0, 0, 2, 0, -596, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 2, 0, 560, 0, 0, 0, 0, 1, 0, -596, 0, 78400>
	sturm
}

//--- Torus for neck Support
#declare T2 = 
quartic {
	<1, 0, 0, 0, 2, 0, 0, 2, 0, -1018, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 2, 0, 918, 0, 0, 0, 0, 1, 0, -1018 0 210681>
	sturm
}

//---- Torus for Stomach Muscles
#declare M1 = 
quartic {
	<1, 0, 0, 0, 2, 0, 0, 2, 0, -477, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 2, 0, 252, 0, 0, 0, 0, 1, 0, -477, 0, 15876>
	sturm
}

//--- Hype for Mid Section
#declare Rib =
intersection {
	quadric { <0.002450740123517, -0.000626525298795, 0.002450740123517>, <0, 0, 0>, <0, 0, 0>, -1 }
	plane { <0, 1, 0>, 33 }
	plane { <0, 1, 0>, -33 inverse }
	translate <0, 33, 0>
}

//---- Ear Commmunication Thingy
#declare EarComm =
object {
	union {
		intersection {
			object { QCone_X scale <24, 14, 14> }
			plane { <1, 0, 0>, -13 }
			plane { <1, 0, 0>, -24 inverse }
		}
		intersection {
			object { QCone_X scale <24, 14, 14> }
			plane { <1, 0, 0>, -5 }
			plane { <1, 0, 0>, -24 inverse }
			translate <-3.5, 0, 0>
		}
		object { Disk_X scale <2, 1.5, 2> translate <-8.2, 0, 0> }
	}
	texture { EarComm_Texture }
	bounded_by { object { UnitBox  scale <10.5, 15.5, 10.5> translate <-15.7, 0, 0> } }
	scale <1, 1, 0.85>
	translate <24, 0, 0>
}

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
//--- Arm
//--- Upper Left Arm
#declare LArm =
union {
	//--- Arm Connection
	union {
		object { T1 translate <0, -13, 0> }
		object { T1 translate <0, -19, 0> }
		object { T1 translate <0, -25, 0> }
		texture { ArmBand_Texture }
		bounded_by { object { UnitBox  scale <21.1, 11.1, 21.1> translate <0, -19, 0> } }
	}
	union {
		object { Sphere scale <17, 52, 18> translate <0, -43.2, 0> }
		object { Sphere scale <17, 52, 17> translate <0, -43.2, 0> }
		object { Disk_X scale <18, 4, 4> translate <0, -84.4, 0> }
		texture { Arm_Texture }
		bounded_by { object { UnitBox  scale <18, 53, 18> translate <0, -43.2, 0> } }
	}
	//--- Elbow
	difference {
		object { Sphere scale <17, 17, 17> translate <0, -84.4, 0> }
		object { UnitBox  scale <1, 20, 20> translate <0, -84.4, 0> }
		texture { Elbow_Texture }
		bounded_by { object { UnitBox  scale <22, 56, 22> translate <0, -46, 0> } }
	}
	//--- Lower Left Arm
	union {
		difference {
			object { Sphere scale <16, 48, 16> translate <0, -34.4, 0> }
			plane { <0, 1, 0>, -63 }
			texture { Arm_Texture }
		}
		union {
			object { T1 scale <0.8, 0.8, 0.8> translate <0, -68.2, 0> }
			object { T1 scale <0.8, 0.8, 0.8> translate <0, -63.4, 0> }
			object { T1 scale <0.8, 0.8, 0.8> translate <0, -58.6, 0> }
			texture { ArmBand_Texture }
		}
		object {
			RightHand	
			scale <0.35, 0.35, 0.35>
			rotate <-100, 0, 0>
			rotate <0, 10, 0>
			translate <-0.7, -70.7, 10>
		}
		rotate <70, 0, 0>
		translate <0, -84.4, 0> 
	}
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++
//--- Gun Arm with Ray
#declare GArm =
union {
	//--- Arm Connection
	union {
		object { T1 translate <0, -13, 0> }
		object { T1 translate <0, -19, 0> }
		object { T1 translate <0, -25, 0> }
		texture { ArmBand_Texture }
		bounded_by { object { UnitBox  scale <21.1, 11.1, 21.1> translate <0, -19, 0> } }
	}
	union {
		object { Sphere scale <17, 52, 18> translate <0, -43.2, 0> }
		object { Sphere scale <17, 52, 17> translate <0, -43.2, 0> }
		object { Disk_X scale <18, 4, 4> translate <0, -84.4, 0> }
		texture { Arm_Texture }
		bounded_by { object { UnitBox  scale <18, 53, 18> translate <0, -43.2, 0> } }
	}
	//--- Elbow
	difference {
		object { Sphere scale <17, 17, 17> translate <0, -84.4, 0> }
		object { UnitBox  scale <1, 20, 20> translate <0, -84.4, 0> }
		texture { Elbow_Texture }
		bounded_by { object { UnitBox  scale <22, 56, 22> translate <0, -46, 0> } }
	}
	//--- Lower Left Arm
	union {
		difference {
			object { Sphere scale <16, 48, 16> translate <0, -34.4, 0> }
			plane { <0, 1, 0>, -63 }
			texture { Arm_Texture }
		}
		union {
			object { T1 scale <0.8, 0.8, 0.8> translate <0, -68.2, 0> }
			object { T1 scale <0.8, 0.8, 0.8> translate <0, -63.4, 0> }
			object { T1 scale <0.8, 0.8, 0.8> translate <0, -58.6, 0> }
			texture { ArmBand_Texture }
		}
		object {
			GunHand	
			rotate <180, 0, 0>
			rotate <0, -90, 0>
			rotate <0, 0, -10>
			translate <0, -70.7, 0>
		}
		rotate <60, 0, 0>								//---- rotates lower arm at elbow 
		translate <0, -84.4, 0> 
	}
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//--- Gun Arm with No Ray
#declare GArm_N =
union {
	//--- Arm Connection
	union {
		object { T1 translate <0, -13, 0> }
		object { T1 translate <0, -19, 0> }
		object { T1 translate <0, -25, 0> }
		texture { ArmBand_Texture }
		bounded_by { object { UnitBox  scale <21.1, 11.1, 21.1> translate <0, -19, 0> } }
	}
	union {
		object { Sphere scale <17, 52, 18> translate <0, -43.2, 0> }
		object { Sphere scale <17, 52, 17> translate <0, -43.2, 0> }
		object { Disk_X scale <18, 4, 4> translate <0, -84.4, 0> }
		texture { Arm_Texture }
		bounded_by { object { UnitBox  scale <18, 53, 18> translate <0, -43.2, 0> } }
	}
	//--- Elbow
	difference {
		object { Sphere scale <17, 17, 17> translate <0, -84.4, 0> }
		object { UnitBox  scale <1, 20, 20> translate <0, -84.4, 0> }
		texture { Elbow_Texture }
		bounded_by { object { UnitBox  scale <22, 56, 22> translate <0, -46, 0> } }
	}
	//--- Lower Left Arm
	union {
		difference {
			object { Sphere scale <16, 48, 16> translate <0, -34.4, 0> }
			plane { <0, 1, 0>, -63 }
			texture { Arm_Texture }
		}
		union {
			object { T1 scale <0.8, 0.8, 0.8> translate <0, -68.2, 0> }
			object { T1 scale <0.8, 0.8, 0.8> translate <0, -63.4, 0> }
			object { T1 scale <0.8, 0.8, 0.8> translate <0, -58.6, 0> }
			texture { ArmBand_Texture }
		}
		object {
			GunHand_N	
			rotate <180, 0, 0>
			rotate <0, -90, 0>
			rotate <0, 0, 0>
			translate <0, -70.7, 0>
		}
		rotate <60, 0, 0>								//---- rotates lower arm at elbow 
		translate <0, -84.4, 0> 
	}
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//--- Arm
//--- Upper Right Arm
#declare RArm =
union {
	//--- Arm Connection
	union {
		object { T1 translate <0, -13, 0> }
		object { T1 translate <0, -19, 0> }
		object { T1 translate <0, -25, 0> }
		texture { ArmBand_Texture }
		bounded_by { object { UnitBox  scale <21.1, 11.1, 21.1> translate <0, -19, 0> } }
	}
	union {
		object { Sphere scale <17, 52, 18> translate <0, -43.2, 0> }
		object { Sphere scale <17, 52, 17> translate <0, -43.2, 0> }
		object { Disk_X scale <18, 4, 4> translate <0, -84.4, 0> }
		texture { Arm_Texture }
		bounded_by { object { UnitBox  scale <18, 53, 18> translate <0, -43.2, 0> } }
	}
	//--- Elbow
	difference {
		object { Sphere scale <17, 17, 17> translate <0, -84.4, 0> }
		object { UnitBox  scale <1, 20, 20> translate <0, -84.4, 0> }
		texture { Elbow_Texture }
		bounded_by { object { UnitBox  scale <22, 56, 22> translate <0, -46, 0> } }
	}
	//--- Lower Left Arm
	union {
		difference {
			object { Sphere scale <16, 48, 16> translate <0, -34.4, 0> }
			plane { <0, 1, 0>, -63 }
			texture { Arm_Texture }
		}
		union {
			object { T1 scale <0.8, 0.8, 0.8> translate <0, -68.2, 0> }
			object { T1 scale <0.8, 0.8, 0.8> translate <0, -63.4, 0> }
			object { T1 scale <0.8, 0.8, 0.8> translate <0, -58.6, 0> }
			texture { ArmBand_Texture }
		}
		object {
			LeftHand	
			scale <0.35, 0.35, 0.35>
			rotate <-110, 0, 0>
			rotate <0, 0, 0>
			translate <0.7, -70.7, 8>
		}
		rotate <40, 0, 0> translate <0, -84.4, 0> 
	}
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//--- Shoulder Wings
#declare Shoulder =
union {
	union {
		object { Disk_X scale <2.4, 16.4, 21.5> translate <-2.4, 0, 0> }
		difference {
			union {
				object { UnitBox  scale <1.4, 28, 30> translate <-6.2, 5.2, 0> }
				object { UnitBox  scale <1.4, 28, 30> translate <-11.2, 5.2, 0> }
				object { UnitBox  scale <1.4, 28, 30> translate <-16.2, 5.2, 0> }
			}
			object { Sphere scale <16, 25, 25> translate <-6.1, 5.3, 0> inverse }
		}
		object { Sphere scale <20, 20, 20> translate <-21.2, -0.8, 0> inverse }
		texture { Shoulder_Texture }
		bounded_by { object { UnitBox  scale <22, 30, 30>	translate <-20.8, 3.9, 0> } }
	}

	//--- Knob
	union {
		object { Disk_X scale <1.5, 10, 10> translate <-20, 0, 0> }
		intersection {
			object { QCone_X scale <44.2, 16, 16> translate <-40.4, 0, 0> }
			plane { <1, 0, 0>, -25 inverse }
			plane { <1, 0, 0>, -18.5 }
		}
		texture { Knob_Texture }
		rotate <0, 0, -40>
		translate <-20, -0.8, 0>
	}
}

#declare EarWire =
object {
	union {
		sphere { <0, 0, 0>, 1.4 }
		sphere { <1.56434, -0.12312, 0>, 1.4 }
		sphere { <3.09017, -0.48943, 0>, 1.4 }
		sphere { <4.5399, -1.08993, 0>, 1.4 }
		sphere { <5.87785, -1.90983, 0>, 1.4 }
		sphere { <7.07107, -2.92893, 0>, 1.4 }
		sphere { <8.09017, -4.12215, 0>, 1.4 }
		sphere { <8.91007, -5.46009, 0>, 1.4 }
		sphere { <9.51056, -6.90983, 0>, 1.4 }
		sphere { <9.87688, -8.43566, 0>, 1.4 }
		sphere { <10, -10, 0>, 1.4 }
		sphere { <9.87688, -11.56434, 0>, 1.4 }
		sphere { <9.51056, -13.09017, 0>, 1.4 }
		sphere { <8.91007, -14.53991, 0>, 1.4 }
		sphere { <8.09017, -15.87785, 0>, 1.4 }
		sphere { <7.07107, -17.07107, 0>, 1.4 }
		sphere { <5.87785, -18.09017, 0>, 1.4 }
		sphere { <4.5399, -18.91006, 0>, 1.4 }
		sphere { <3.09017, -19.51056, 0>, 1.4 }
		sphere { <1.56434, -19.87688, 0>, 1.4 }
		sphere { <0, -20, 0>, 1.4 }
		sphere { <-1.56435, -20.12312, 0>, 1.4 }
		sphere { <-3.09017, -20.48944, 0>, 1.4 }
		sphere { <-4.53991, -21.08994, 0>, 1.4 }
		sphere { <-5.87785, -21.90983, 0>, 1.4 }
		sphere { <-7.07107, -22.92893, 0>, 1.4 }
		sphere { <-8.09017, -24.12215, 0>, 1.4 }
		sphere { <-8.91007, -25.4601, 0>, 1.4 }
		sphere { <-9.51057, -26.90983, 0>, 1.4 }
		sphere { <-9.87688, -28.43566, 0>, 1.4 }
		sphere { <-10, -30, 0>, 1.4 }
		sphere { <-9.99446, -31.50386, 0>, 1.4 }
		sphere { <-9.97783, -33.00763, 0>, 1.4 }
		sphere { <-9.95011, -34.51123, 0>, 1.4 }
		sphere { <-9.91132, -36.01458, 0>, 1.4 }
		sphere { <-9.86144, -37.51761, 0>, 1.4 }
		sphere { <-9.80048, -39.02023, 0>, 1.4 }
		sphere { <-9.72845, -40.52236, 0>, 1.4 }
		sphere { <-9.64534, -42.02391, 0>, 1.4 }
		sphere { <-9.55117, -43.52482, 0>, 1.4 }
		sphere { <-9.44594, -45.02499, 0>, 1.4 }
		sphere { <-9.32965, -46.52434, 0>, 1.4 }
		sphere { <-9.20231, -48.02279, 0>, 1.4 }
		sphere { <-9.06393, -49.52027, 0>, 1.4 }
		sphere { <-8.91451, -51.01668, 0>, 1.4 }
		sphere { <-8.75407, -52.51196, 0>, 1.4 }
		sphere { <-8.5826, -54.006, 0>, 1.4 }
		sphere { <-8.40013, -55.49875, 0>, 1.4 }
		sphere { <-8.20666, -56.9901, 0>, 1.4 }
		sphere { <-8.0022, -58.48, 0>, 1.4 }
		sphere { <-7.78677, -59.96834, 0>, 1.4 }
	}
	texture { Wire_Texture }
	bounded_by { sphere { <0, -29.98417, 0>, 36.761831 } }
}
 
//	End Declares
//^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

//---- Complete Body
#declare Body =
union {
	//--- Complete Helmet
	object {
		union {
			
			difference {
				union {
					object { Sphere scale <30, 30, 30> translate <-2, 22.7, -14.7> }				
					object { Sphere scale <30, 30, 30> translate <2, 22.7, -14.7> }
					object { Sphere scale <25, 25, 23.5> translate <0, 0, -14.7> }
				}
				object { Disk_Z scale <12.2, 12.2, 20> translate <-13.4, 23, -29.2> }
				object { Disk_Z scale <12.2, 12.2, 20> translate <13.4, 23, -29.2> }
				object { Disk_Z scale <21, 21, 20> translate <0, 0, -29.2> }
				object { UnitBox  scale <21, 13, 20> translate <0, 10.4, -29.2> }
				object { UnitBox  scale <21, 13, 20> translate <0, -15.7, -29.2> }
				texture { Helmet_Texture }
				bounded_by { object { UnitBox  scale <33, 55, 33> translate <0, 0, -14.7> } }
			}

			//----- Chin Strap
			object {
				difference {
					union {
						intersection {
							object { Connector_2 }
							plane { <1, 0, 0>, 16.387693 }
							plane { <1, 0, 0>, 12.542536 inverse }
							translate <-16.387693, 0, 0>
							scale <2.275772, 1, 1>
							translate <-7.200938, 0, 0>
							rotate <0, 180, 0>
							rotate <0, 0, -69.829347>
							rotate <0, 90, 0>
							translate <-2.7, -4.3, -17.5>
						}
						object {
							Dot
							scale <13.7, 13.7, 13.7>
							translate <-2.7, -14.1, -21.1>
						}
						intersection {
							object { Connector_2 }
							plane { <1, 0, 0>, 11.978087 }
							plane { <1, 0, 0>, 8.305973 inverse }
							translate <-11.978087, 0, 0>
							scale <1.80136, 1, 1>
							translate <-6.649469, 0, 0>
							rotate <0, 180, 0>
							rotate <0, 0, -56.309932>
							rotate <0, 90, 0>
							translate <-2.7, -14.1, -21.1>
						}
						object {
							Dot
							scale <9.5, 9.5, 9.5>
							translate <-2.7, -21.3, -25.9>
						}
						intersection {
							object { Connector_2 }
							plane { <1, 0, 0>, 8.764492 }
							plane { <1, 0, 0>, 6.089016 inverse }
							translate <-8.764492, 0, 0>
							scale <2.391274, 1, 1>
							translate <-3.665197, 0, 0>
							rotate <0, 180, 0>
							rotate <0, 0, -56.944177>
							rotate <0, 90, 0>
							translate <-2.7, -21.3, -25.9>
						}
						object {
							Dot
							scale <6.6, 6.6, 6.6>
							translate <-2.7, -27.6, -30>
						}
						intersection {
							object { Connector_2 }
							plane { <1, 0, 0>, 16.387693 }
							plane { <1, 0, 0>, 12.542536 inverse }
							translate <-16.387693, 0, 0>
							scale <2.275772, 1, 1>
							translate <-7.200938, 0, 0>
							rotate <0, 180, 0>
							rotate <0, 0, -69.829347>
							rotate <0, 90, 0>
							translate <2.7, -4.3, -17.5>
						}
						object {
							Dot
							scale <13.7, 13.7, 13.7>
							translate <2.7, -14.1, -21.1>
						}
						intersection {
							object { Connector_2 }
							plane { <1, 0, 0>, 11.978087 }
							plane { <1, 0, 0>, 8.305973 inverse }
							translate <-11.978087, 0, 0>
							scale <1.80136, 1, 1>
							translate <-6.649469, 0, 0>
							rotate <0, 180, 0>
							rotate <0, 0, -56.309932>
							rotate <0, 90, 0>
							translate <2.7, -14.1, -21.1>
						}
						object {
							Dot
							scale <9.5, 9.5, 9.5>
							translate <2.7, -21.3, -25.9>
						}
						intersection {
							object { Connector_2 }
							plane { <1, 0, 0>, 8.764492 }
							plane { <1, 0, 0>, 6.089016 inverse }
							translate <-8.764492, 0, 0>
							scale <2.391274, 1, 1>
							translate <-3.665197, 0, 0>
							rotate <0, 180, 0>
							rotate <0, 0, -56.944177>
							rotate <0, 90, 0>
							translate <2.7, -21.3, -25.9>
						}
						object {
							Dot
							scale <6.6, 6.6, 6.6>
							translate <2.7, -27.6, -30>
						}
					}
					//--- Cut out Mouth
					object { MCut scale <1, 2, 1> translate <0, -15, 0> }
				}
				texture { Helmet_Texture }
				bounded_by { object { UnitBox  scale <32, 45, 32> translate <0, 7.9, -14> } }
				scale <1.17, 1.1, 1>
				translate <0, 0, 1>
			}

			//--- Ear Comms
			object { EarComm rotate <0, 180, 0> translate <-20, 4.4, -15> }
			object { EarComm translate <20, 4.4, -15> }

			union {
				//--- Helmet Neck
				difference {
					union {
						object { T1 translate <0, -15, -11> }
						object { T1 translate <0, -21, -11> }
						object { T1 translate <0, -27, -11> }
						object { T1 translate <0, -33, -11> }
						object { T1 translate <0, -39, -11> }
						object { T1 scale <1.1, 1, 1.1> translate <0, -45, -11> }
					}
					object { MCut scale <1, 2.5, 1> translate <0, -16, 0> }
					texture { Neck_Texture }
					bounded_by { object { UnitBox  scale <22, 22, 22> translate <0, -33, -11> } } 
				}

				//-- Neck Ring
				object {
					T2
					translate <0, -50, -11>
					texture { NeckRing_Texture }
				}

				//-- Shoulder Harness
				union {
					difference {
						object { Sphere scale <51, 24, 36> translate <0, -71, -11> }
						object { Cylinder_Z scale <76, 24, 1> translate <0, -93.7, 0> }
						plane { <1, 0, 0>, 40 inverse }
						plane { <1, 0, 0>, -40 }
					}
					object { Sphere scale <5, 20, 21> translate <0, -64.7, -25.5> }	
					object { Sphere scale <5, 20, 21> translate <5, -64.7, -25.5> }	
					object { Sphere scale <5, 20, 21> translate <10, -64.7, -25.5> }		
					object { Sphere scale <5, 20, 21> translate <-5, -64.7, -25.5> }	
					object { Sphere scale <5, 20, 21> translate <-10, -64.7, -25.5> }	
					texture { Harness_Texture }
					bounded_by { object { UnitBox  scale <43, 16, 40> translate <0, -59, -10.7> } }
				}
				bounded_by { object { UnitBox  scale <43, 33, 40> translate <0, -42, -10.7> } }

			}
			bounded_by { object { UnitBox  scale <43, 66, 40> translate <0, -10, -10.7> } }
		
		}
	}
	
	//---- Chest & Shoulder
	union {
		object { Shoulder translate <-38, -70, -11> }
		object { Shoulder rotate <0, 180, 0> translate <38, -70, -11> }
		//--- Chest
		union {
			object { Sphere scale <35, 33, 38> translate <-12.2, -84.2, -11> }
			object { Sphere scale <35, 33, 38> translate <12.2, -84.2, -11> }
			object { Sphere scale <30, 38, 33> translate <-17, -103.5, -11> }
			object { Sphere scale <30, 38, 33> translate <17, -103.5, -11> }
			object { Rib translate <17, -187.6, -11> }
			object { Rib translate <-17, -187.6, -11> }
			texture { Chest_Texture }
			bounded_by { object { UnitBox  scale <51, 72, 40>	translate <0, -120, -11> } }
		}

		//--- Stomach Musles
		union { 
			object { M1 translate <-5, -180, -23> }
			object { M1 translate <-5, -165, -23> }
			object { M1 translate <-5, -150, -23> }
			object { M1 translate <-5, -135, -23> }
			object { M1 translate <5, -180, -23> }
			object { M1 translate <5, -165, -23> }
			object { M1 translate <5, -150, -23> }
			object { M1 translate <5, -135, -23> }
			object { Sphere scale <29, 26, 19> translate <0, -113, -26> }
			texture { Stomach_Texture }
			bounded_by { object { UnitBox  scale <30, 53, 24>	translate <0, -140, -23> } }
		}
	}
	object { EarWire translate <35, 4.4, -15> }
	object { EarWire rotate <0, 180, 0> translate <-35, 4.4, -15> }
	bounded_by { object { UnitBox  scale <155, 175, 155>	translate <0, -99, -11> } }
}


//--- Rex 1
union {
	object { Head }
	object { Body }
	object { GArm_N rotate <50, 0, 0> rotate <0, 0,  10> translate < 60, -70, -11> }
	object { LArm   rotate <30, 0, 0> rotate <0, 0, -15> translate <-60, -70, -11> }
	bounded_by { object { UnitBox  scale <155, 175, 155> translate <0, -99, -11> } }
	scale <1.8, 1.8, 1.8>
	rotate <0, 40, 0>
	translate <200, 920, -3200>
}

//--- Rex 2 the Slug Slayer
union {
	union {
		object { Head }
		object { Body }
		bounded_by { object { UnitBox  scale <155, 175, 155> translate <0, -99, -11> } }
	}
	object { GArm rotate <50, 0, 0> rotate <0, 0,  10> translate < 60, -70, -11> }
	object { LArm rotate <30, 0, 0> rotate <0, 0, -15> translate <-60, -70, -11> }
	scale <1.8, 1.8, 1.8>
	rotate <0, 140, 0>
	translate <-100, 920, -3000>
}
